Module: ShinyThemes::RendersTheme::ClassMethods
- Defined in:
- lib/shiny_themes/renders_theme.rb
Instance Method Summary collapse
-
#renders_theme(name, options = {}) ⇒ Theme
Use the theme and options for all rendering in this controller option options [String] :layout ('application') Default layout for theme.
Instance Method Details
#renders_theme(name, options = {}) ⇒ Theme
Use the theme and options for all rendering in this controller option options [String] :layout ('application') Default layout for theme
48 49 50 |
# File 'lib/shiny_themes/renders_theme.rb', line 48 def renders_theme(name, = {}) self.theme = Theme.new(.merge(name: name, layout: [:layout])) end |